@@ -4,10 +4,9 @@
 from shlex import quote
 
 # for file input and multipart, rather than converting them to body, we use curl's actual syntax
-from dothttp import HttpDef
 
 
-def to_curl(request: HttpDef, bodydata=None):
+def to_curl(url, method, bodydata=None):
     parts = []
     if isinstance(bodydata, list):
         for p in bodydata:
@@ -22,4 +21,4 @@ def to_curl(request: HttpDef, bodydata=None):
         elif v:
             flat_parts.append(quote(v))
 
-    return f'curl -X {request.method} --url {request.url} \\\n' + ' \\\n'.join(flat_parts)
+    return f'curl -X {method} --url {url} \\\n' + ' \\\n'.join(flat_parts)
